@@ -9,3 +9,7 @@ class BackupUtilsConfig(AppConfig):
     PROJECT_NAME = Path(settings.BASE_DIR).name
     JSON_FILENAME = 'django-backup-utils-fullbackup.json'
     DUMPINFO = 'django-backup-utils-backup-info.txt'
+    try:
+        BACKUP_IGNORE_CONSISTENCY = settings.BACKUP_IGNORE_CONSISTENCY
+    except AttributeError:
+        BACKUP_IGNORE_CONSISTENCY = False
