@@ -9,7 +9,7 @@ from django_backup_utils.helpers import get_backup_name
 
 class Command(BaseCommand):
 
-    def find_backup(self, hostname="", projectname=""):
+    def find_backup(self, hostname="", projectname="", all=False):
         files = os.listdir(settings.BACKUP_ROOT)
         paths = [os.path.join(settings.BACKUP_ROOT, basename) for basename in files]
         correct = []
@@ -30,7 +30,7 @@ class Command(BaseCommand):
 
     def handle(self, hostname, projectname, all, *args, **options):
         if os.path.exists(settings.BACKUP_ROOT):
-            backups = self.find_backup(hostname, projectname)
+            backups = self.find_backup(hostname, projectname, all)
             for backup in backups:
                 print(f"{backup}\t\t{time.ctime(os.path.getctime(backup))}")
         else:
